package perso.gdalconst;

import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigIntegerValue;

/**
 * @author Florent Jitiaux
 * 
 */
public enum ColorInterpretation implements SwigIntegerValue {

	/**
	 * GCI_AlphaBand(6) : Alpha band of RGBA image (0=transparent, 255=opaque) (color interpretation)
	 */
	ALPHA_BAND("GCI_AlphaBand"),
	/**
	 * GCI_BlackBand(13) : Black band of CMYK image (color interpretation)
	 */
	BLACK_BAND("GCI_BlackBand"),
	/**
	 * GCI_BlueBand(5) : Blue band of RGBA image (color interpretation)
	 */
	BLUE_BAND("GCI_BlueBand"),
	/**
	 * GCI_CyanBand(10) : Cyan band of CMYK image (color interpretation)
	 */
	CYAN_BAND("GCI_CyanBand"),
	/**
	 * GCI_GrayIndex(1) : greyscale (color interpretation)
	 */
	GRAY_INDEX("GCI_GrayIndex"),
	/**
	 * GCI_GreenBand(4) : Green band of RGBA image (color interpretation)
	 */
	GREEN_BAND("GCI_GreenBand"),
	/**
	 * GCI_HueBand(7) : Hue band of HLS image (color interpretation)
	 */
	HUE_BAND("GCI_HueBand"),
	/**
	 * GCI_LightnessBand(9) : Lightness band of HLS image (color interpretation)
	 */
	LIGHTNESS_BAND("GCI_LightnessBand"),
	/**
	 * GCI_MagentaBand(11) : Magenta band of CMYK image (color interpretation)
	 */
	MAGENTA_BAND("GCI_MagentaBand"),
	/**
	 * GCI_PaletteIndex(2) : paletted with color table (color interpretation)
	 */
	PALETTE_INDEX("GCI_PaletteIndex"),
	/**
	 * GCI_RedBand(3) : Red band of RGBA image (color interpretation)
	 */
	RED_BAND("GCI_RedBand"),
	/**
	 * GCI_SaturationBand(8) : Saturation band of HLS image (color interpretation)
	 */
	SATURATION_BAND("GCI_SaturationBand"),
	/**
	 * GCI_Undefined(0) : undefined (color interpretation)
	 */
	UNDEFINED("GCI_Undefined"),
	/**
	 * GCI_YCbCr_CbBand(15) : Cb Luminance (color interpretation)
	 */
	YCBCR_CB_BAND("GCI_YCbCr_CbBand"),
	/**
	 * GCI_YCbCr_CrBand(16) : Cr Luminance (color interpretation)
	 */
	YCBCR_CR_BAND("GCI_YCbCr_CrBand"),
	/**
	 * GCI_YCbCr_YBand(14) : Y Luminance (color interpretation)
	 */
	YCBCR_Y_BAND("GCI_YCbCr_YBand"),
	/**
	 * GCI_YellowBand(12) : Yellow band of CMYK image (color interpretation)
	 */
	YELLOW_BAND("GCI_YellowBand");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private ColorInterpretation(String name) {

		this.name = name;
	}

	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public int getSwigValue() {
		switch (this) {
			case ALPHA_BAND:
				return gdalconst.GCI_AlphaBand;
			case BLACK_BAND:
				return gdalconst.GCI_BlackBand;
			case BLUE_BAND:
				return gdalconst.GCI_BlueBand;
			case CYAN_BAND:
				return gdalconst.GCI_CyanBand;
			case GRAY_INDEX:
				return gdalconst.GCI_GrayIndex;
			case GREEN_BAND:
				return gdalconst.GCI_GreenBand;
			case HUE_BAND:
				return gdalconst.GCI_HueBand;
			case LIGHTNESS_BAND:
				return gdalconst.GCI_LightnessBand;
			case MAGENTA_BAND:
				return gdalconst.GCI_MagentaBand;
			case PALETTE_INDEX:
				return gdalconst.GCI_PaletteIndex;
			case RED_BAND:
				return gdalconst.GCI_RedBand;
			case SATURATION_BAND:
				return gdalconst.GCI_SaturationBand;
			case UNDEFINED:
				return gdalconst.GCI_Undefined;
			case YCBCR_CB_BAND:
				return gdalconst.GCI_YCbCr_CbBand;
			case YCBCR_CR_BAND:
				return gdalconst.GCI_YCbCr_CrBand;
			case YCBCR_Y_BAND:
				return gdalconst.GCI_YCbCr_YBand;
			case YELLOW_BAND:
				return gdalconst.GCI_YellowBand;
			default:
				return gdalconst.GCI_Undefined;
		}
	}

	/**
	 * Get this ColorInterpretation by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the ColorInterpretation which corresponds to the name.
	 */
	public static ColorInterpretation getConstantByName(String name) {
		for (ColorInterpretation colorInterpretation : ColorInterpretation.values()) {
			if (name.equalsIgnoreCase(colorInterpretation.name)) {
				return colorInterpretation;
			}
		}

		return null;
	}

	/**
	 * Get this ColorInterpretation by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the ColorInterpretation which corresponds to the value.
	 */
	public static ColorInterpretation getConstantByValue(int swigValue) {
		for (ColorInterpretation colorInterpretation : ColorInterpretation.values()) {
			if (swigValue == colorInterpretation.getSwigValue()) {
				return colorInterpretation;
			}
		}

		return null;
	}

}