package perso.gdalconst;

import org.gdal.gdal.gdal;
import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigIntegerValue;

/**
 * @author Florent Jitiaux
 * 
 */
public enum DataType implements SwigIntegerValue {

	/**
	 * GDT_Byte(1) : Eight bit unsigned integer (data type)
	 */
	BYTE("GDT_Byte"),
	/**
	 * GDT_CFloat32(10) : Complex Float32 (data type)
	 */
	CFLOAT_32("GDT_CFloat32"),
	/**
	 * GDT_CFloat64(11) : Complex Float64 (data type)
	 */
	CFLOAT_64("GDT_CFloat64"),
	/**
	 * GDT_CInt16(8) : Complex Int16 (data type)
	 */
	CINT_16("GDT_CInt16"),
	/**
	 * GDT_CInt32(9) : Complex Int32 (data type)
	 */
	CINT_32("GDT_CInt32"),
	/**
	 * GDT_Float32(6) : Thirty two bit floating point (data type)
	 */
	FLOAT_32("GDT_Float32"),
	/**
	 * GDT_Float64(7) : Sixty four bit floating point (data type)
	 */
	FLOAT_64("GDT_Float64"),
	/**
	 * GDT_Int16(3) : Sixteen bit signed integer (data type)
	 */
	INT_16("GDT_Int16"),
	/**
	 * GDT_Int32(5) : Thirty two bit signed integer (data type)
	 */
	INT_32("GDT_Int32"),
	/**
	 * GDT_TypeCount(12) : Maximum type (data type)
	 */
	TYPE_COUNT("GDT_TypeCount"),
	/**
	 * GDT_UInt16(2) : Sixteen bit unsigned integer (data type)
	 */
	UINT_16("GDT_UInt16"),
	/**
	 * GDT_UInt32(4) : Thirty two bit unsigned integer (data type)
	 */
	UINT_32("GDT_UInt32"),
	/**
	 * GDT_Unknown(0) : Unknown (data type)
	 */
	UNKNOWN("GDT_Unknown");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private DataType(String name) {
		this.name = name;
	}

	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public int getSwigValue() {

		switch (this) {
			case BYTE:
				return gdalconst.GDT_Byte;
			case CFLOAT_32:
				return gdalconst.GDT_CFloat32;
			case CFLOAT_64:
				return gdalconst.GDT_CFloat64;
			case CINT_16:
				return gdalconst.GDT_CInt16;
			case CINT_32:
				return gdalconst.GDT_CInt32;
			case FLOAT_32:
				return gdalconst.GDT_Float32;
			case FLOAT_64:
				return gdalconst.GDT_Float64;
			case INT_16:
				return gdalconst.GDT_Int16;
			case INT_32:
				return gdalconst.GDT_Int32;
			case TYPE_COUNT:
				return gdalconst.GDT_TypeCount;
			case UINT_16:
				return gdalconst.GDT_UInt16;
			case UINT_32:
				return gdalconst.GDT_UInt32;
			case UNKNOWN:
				return gdalconst.GDT_Unknown;
			default:
				return gdalconst.GDT_Unknown;
		}
	}

	public int getDataTypeSize() {
		return gdal.GetDataTypeSize(this.getSwigValue());
	}

	public static String getDataTypeName(int dataTypeValue) {

		for (DataType dataType : DataType.values()) {
			if (dataTypeValue == dataType.getSwigValue()) {
				return dataType.name;
			}
		}

		return DataType.UNKNOWN.name;
	}

	public static DataType getDataTypeByName(String dataTypeName) {

		for (DataType dataType : DataType.values()) {
			if (dataTypeName.equalsIgnoreCase(dataType.name)) {
				return dataType;
			}
		}

		return DataType.UNKNOWN;
	}

	public boolean isComplex() {
		if (gdal.DataTypeIsComplex(this.getSwigValue()) == 1) {
			return true;
		}
		else {
			return false;
		}
	}

	/**
	 * Get this DataType by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the DataType which corresponds to the name.
	 */
	public static DataType getConstantByName(String name) {
		for (DataType dataType : DataType.values()) {
			if (name.equalsIgnoreCase(dataType.name)) {
				return dataType;
			}
		}

		return null;
	}

	/**
	 * Get this DataType by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the DataType which corresponds to the value.
	 */
	public static DataType getConstantByValue(int swigValue) {
		for (DataType dataType : DataType.values()) {
			if (swigValue == dataType.getSwigValue()) {
				return dataType;
			}
		}

		return null;
	}

}