package perso.gdalconst;

import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigIntegerValue;

/**
 * @author Florent Jitiaux
 * 
 */
public enum EscapeString implements SwigIntegerValue {

	/**
	 * CPLES_BackslashQuotable(0).
	 * <p>
	 * This scheme turns a binary string into a form suitable to be placed within double quotes as a string constant.
	 * The backslash, quote, '\\0' and newline characters are all escaped in the usual C style.
	 */
	BACKSLASH_QUOTABLE("CPLES_BackslashQuotable"),
	/**
	 * CPLES_CSV(4).
	 * <p>
	 * If the values contains commas, double quotes, or newlines it placed in double quotes, and double quotes in the
	 * value are doubled. Suitable for use when constructing field values for .csv files. Note that CPLUnescapeString()
	 * currently does not support this format, only CPLEscapeString(). See cpl_csv.cpp for csv parsing support.
	 */
	CSV("CPLES_CSV"),
	/**
	 * CPLES_SQL(3).
	 * <p>
	 * All single quotes are replaced with two single quotes. Suitable for use when constructing literal values for SQL
	 * commands where the literal will be enclosed in single quotes.
	 */
	SQL("CPLES_SQL"),
	/**
	 * CPLES_URL(2).
	 * <p>
	 * Everything except alphanumerics and the underscore are converted to a percent followed by a two digit hex
	 * encoding of the character (leading zero supplied if needed). This is the mechanism used for encoding values to be
	 * passed in URLs.
	 */
	URL("CPLES_URL"),
	/**
	* CPLES_XML(1).
	* <p>
	* This scheme converts the '<', '<' and '&' characters into
	* their XML/HTML equivelent (&gt;, &lt; and &amp;) making a string safe
	* to embed as CDATA within an XML element.  The '\\0' is not escaped and
	* should not be included in the input.
	*/
	XML("CPLES_XML");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private EscapeString(String name) {
		this.name = name;
	}

	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public int getSwigValue() {
		switch (this) {
			case BACKSLASH_QUOTABLE:
				return gdalconst.CPLES_BackslashQuotable;
			case CSV:
				return gdalconst.CPLES_CSV;
			case SQL:
				return gdalconst.CPLES_SQL;
			case URL:
				return gdalconst.CPLES_URL;
			case XML:
				return gdalconst.CPLES_XML;
			default:
				return gdalconst.CPLES_CSV;
		}
	}

	/**
	 * Get this EscapeString by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the EscapeString which corresponds to the name.
	 */
	public static EscapeString getConstantByName(String name) {
		for (EscapeString escapeString : EscapeString.values()) {
			if (name.equalsIgnoreCase(escapeString.name)) {
				return escapeString;
			}
		}

		return null;
	}

	/**
	 * Get this EscapeString by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the EscapeString which corresponds to the value.
	 */
	public static EscapeString getConstantByValue(int swigValue) {
		for (EscapeString escapeString : EscapeString.values()) {
			if (swigValue == escapeString.getSwigValue()) {
				return escapeString;
			}
		}

		return null;
	}
}