package perso.gdalconst;

import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigIntegerValue;

/**
 * @author Florent Jitiaux
 * 
 */
public enum MaskBandFlag implements SwigIntegerValue {

	/**
	 * GMF_ALL_VALID(0x01) (mask band flag). There are no invalid pixels, all mask values will be 255. When used this
	 * will normally be the only flag set.
	 */
	ALL_VALID("GMF_ALL_VALID"),

	/**
	 * GMF_ALPHA(0x04) (mask band flag). The mask band is actually an alpha band and may have values other than 0 and
	 * 255.
	 */
	ALPHA("GMF_ALPHA"),

	/**
	 * GMF_NODATA(0x08) (mask band flag). Indicates the mask is actually being generated from nodata values. (mutually
	 * exclusive of GMF_ALPHA)
	 */
	NODATA("GMF_NODATA"),

	/**
	 * GMF_PER_DATASET(0x02) (mask band flag). The mask band is shared between all bands on the dataset.
	 */
	PER_DATASET("GMF_PER_DATASET");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private MaskBandFlag(String name) {
		this.name = name;
	}

	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public int getSwigValue() {
		switch (this) {
			case ALL_VALID:
				return gdalconst.GMF_ALL_VALID;
			case ALPHA:
				return gdalconst.GMF_ALPHA;
			case NODATA:
				return gdalconst.GMF_NODATA;
			case PER_DATASET:
				return gdalconst.GMF_PER_DATASET;
			default:
				return gdalconst.GMF_ALL_VALID;

		}
	}

	/**
	 * Get this MaskBandFlag by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the MaskBandFlag which corresponds to the name.
	 */
	public static MaskBandFlag getConstantByName(String name) {
		for (MaskBandFlag maskBandFlag : MaskBandFlag.values()) {
			if (name.equalsIgnoreCase(maskBandFlag.name)) {
				return maskBandFlag;
			}
		}

		return null;
	}

	/**
	 * Get this MaskBandFlag by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the MaskBandFlag which corresponds to the value.
	 */
	public static MaskBandFlag getConstantByValue(int swigValue) {
		for (MaskBandFlag maskBandFlag : MaskBandFlag.values()) {
			if (swigValue == maskBandFlag.getSwigValue()) {
				return maskBandFlag;
			}
		}

		return null;
	}

}