package perso.gdalconst;

import org.gdal.gdalconst.gdalconst;

import perso.gdalconst.interfaces.SwigIntegerValue;

/**
 * @author Florent Jitiaux
 * 
 */
public enum ResamplingAlgorithm implements SwigIntegerValue {

	/**
	 * GRA_Bilinear(1) : Bilinear (2x2 kernel) (warping algorithm)
	 */
	BILINEAR("GRA_Bilinear"),
	/**
	 * GRA_Cubic(2) : Cubic Convolution Approximation (4x4 kernel) (warping algorithm)
	 */
	CUBIC("GRA_Cubic"),
	/**
	 * GRA_CubicSpline(3) : Cubic B-Spline Approximation (4x4 kernel) (warping algorithm)
	 */
	CUBIC_SPLINE("GRA_CubicSpline"),
	/**
	 * GRA_Lanczos(4) : Lanczos windowed sinc interpolation (6x6 kernel) (warping algorithm)
	 */
	LANCZOS("GRA_Lanczos"),
	/**
	 * GRA_NearestNeighbour(0) : Nearest neighbour (select on one input pixel) (warping algorithm)
	 */
	NEAREST_NEIGHBOUR("GRA_NearestNeighbour"),
	AVERAGE("GRA_Average"),
	MODE("GRA_Mode");

	/**
	 * The name of the constant as defined in the Gdal project.
	 */
	private String name;

	/**
	 * Default constructor.
	 * 
	 * @param name
	 *            - name of the constant.
	 */
	private ResamplingAlgorithm(String name) {

		this.name = name;
	}

	@Override
	public String getName() {
		return this.name;
	}

	@Override
	public int getSwigValue() {
		switch (this) {
			case BILINEAR:
				return gdalconst.GRA_Bilinear;
			case CUBIC:
				return gdalconst.GRA_Cubic;
			case CUBIC_SPLINE:
				return gdalconst.GRA_CubicSpline;
			case LANCZOS:
				return gdalconst.GRA_Lanczos;
			case NEAREST_NEIGHBOUR:
				return gdalconst.GRA_NearestNeighbour;
			case AVERAGE:
				return gdalconst.GRA_Average;
			case MODE:
				return gdalconst.GRA_Mode;
			default:
				return gdalconst.GRA_Bilinear;
		}
	}

	/**
	 * Get this ResamplingAlgorithm by entering its Gdal name as defined in the Gdal project.
	 * 
	 * @param name
	 *            - the Gdal name.
	 * @return the ResamplingAlgorithm which corresponds to the name.
	 */
	public static ResamplingAlgorithm getConstantByName(String name) {
		for (ResamplingAlgorithm resamplingAlgorithm : ResamplingAlgorithm.values()) {
			if (name.equalsIgnoreCase(resamplingAlgorithm.name)) {
				return resamplingAlgorithm;
			}
		}

		return null;
	}

	/**
	 * Get this ResamplingAlgorithm by entering its Gdal value as defined in the Gdal project.
	 * 
	 * @param swigValue
	 *            - the Gdal value.
	 * @return the ResamplingAlgorithm which corresponds to the value.
	 */
	public static ResamplingAlgorithm getConstantByValue(int swigValue) {
		for (ResamplingAlgorithm resamplingAlgorithm : ResamplingAlgorithm.values()) {
			if (swigValue == resamplingAlgorithm.getSwigValue()) {
				return resamplingAlgorithm;
			}
		}

		return null;
	}
}